@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
-#    Monk is a lightweight schema/query framework for document databases.
-#    Copyright © 2011  Andrey Mikhaylenko
+#    Monk is an unobtrusive data modeling, manipulation and validation library.
+#    Copyright © 2011—2013  Andrey Mikhaylenko
 #
 #    This file is part of Monk.
 #
@@ -35,7 +35,7 @@ def walk_dict(data):
         therefore can be further unwrapped.
     """
     assert hasattr(data, '__getitem__')
-    for key, value in data.iteritems():
+    for key, value in data.items():
         if isinstance(value, dict):
             yield (key,), None
             for keys, value in walk_dict(value):
